@@ -12,3 +12,10 @@ class ConfigView(CustomModelViewSet):
     model_class = Config
     serializer_class = ConfigSerializer
     permission_classes = [IsAuthenticatedOrReadOnly]
+    ppagination_class = None
+    filterset_fields = {
+        'config_type': {
+            'field_type': 'int',
+            'lookup_expr': ''
+        }
+    }
