@@ -47,7 +47,7 @@ class ChatConsumer(WebsocketConsumer):
             event_chat_queryset = eventChat.objects.get(pk=_id)
             event_chat_queryset.state = 1
             event_chat_queryset.save()
-            data['chat_id'] = _id
+            data['id'] = _id
             # Send message to room group
             async_to_sync(self.channel_layer.group_send)(
                 self.room_group_name,
@@ -68,7 +68,7 @@ class ChatConsumer(WebsocketConsumer):
             event_chat_queryset.state = 0
             event_chat_queryset.save()
             send_data = {
-                'chat_id': _id,
+                'id': _id,
                 'state': data['state']
             }
             async_to_sync(self.channel_layer.group_send)(
