@@ -13,3 +13,10 @@ class EventLivePPT(AbstractEventLivePPT):
 
     class Meta:
         db_table = 'event_live_ppt'
+
+class EventLivePPTCurrent(AbstractRelationTime):
+    event_id = models.IntegerField(verbose_name='活动id')
+    activeIndex = models.IntegerField(verbose_name='ppt页码')
+
+    class Meta:
+        db_table = 'event_live_ppt_current'
\ No newline at end of file
