@@ -1,6 +1,8 @@
 import random
 from bluedot_rest_framework.utils.viewsets import CustomModelViewSet, AllView
 from bluedot_rest_framework.wechat import App
+from rest_framework import status
+from rest_framework.response import Response
 from .models import WeChatResponseMaterial, WeChatResponseEvent
 from .serializers import WeChatResponseMaterialSerializer, WeChatResponseEventSerializer
 
@@ -36,16 +38,20 @@ class WeChatResponseEventView(CustomModelViewSet):
         },
     }
 
-    def perform_create(self, serializer):
-        if self.request.data.get('event_type') == 2:
+    def create(self, request, *args, **kwargs):
+        if request.data['event_type'] == 2:
             event_key = str(random.uniform(1, 10))
-            result = App(self.request.data.get('appid')).qrcode.create({
+            result = App(request.data['appid']).qrcode.create({
                 'action_name': 'QR_LIMIT_STR_SCENE',
                 'action_info': {
                     'scene': {'scene_str': event_key},
                 }
             })
-            qrcode_ticket = result['ticket']
-            serializer.save(event_key=event_key, qrcode_ticket=qrcode_ticket)
-        else:
-            serializer.save()
+            request.data['qrcode_ticket'] = result['ticket']
+            request.data['qrcode_url'] = result['url']
+            request.data['event_key'] = event_key
+        serializer = self.get_serializer(data=request.data)
+        serializer.is_valid(raise_exception=True)
+        self.perform_create(serializer)
+        headers = self.get_success_headers(serializer.data)
+        return Response(serializer.data, status=status.HTTP_201_CREATED, headers=headers)
