@@ -1,9 +1,9 @@
 from rest_framework.response import Response
 from rest_framework.decorators import api_view, permission_classes
-
+from bluedot_rest_framework import import_string
 from bluedot_rest_framework.wechat import OfficialAccount
-from apps.user.models import User
-from apps.user.serializers import UserSerializer
+User = import_string('user.models')
+UserSerializer = import_string('user.serializers')
 
 
 @api_view(['POST'])
