@@ -6,13 +6,16 @@ from django.http import HttpResponse, HttpResponseRedirect
 from rest_framework.views import APIView
 from rest_framework.permissions import IsAuthenticatedOrReadOnly
 from rest_framework.response import Response
-from bluedot_rest_framework.utils.jwt_token import jwt_get_wechatid_handler
-
+from bluedot_rest_framework.utils.jwt_token import jwt_get_wechatid_handler, jwt_get_userid_handler
+from bluedot_rest_framework import import_string
 from . import App, WXBizDataCrypt, official_account_oauth
 from .handle import WeChatUserSet
 from .models import WeChatUser
 from .serializers import WeChatUserSerializer
 
+User = import_string('user.models')
+UserSerializer = import_string('user.serializers')
+
 
 class JSSdk(APIView):
     permission_classes = ()
@@ -89,13 +92,44 @@ class OAuth(APIView):
             return HttpResponseRedirect(url)
 
 
+class OAuthDev(APIView):
+    permission_classes = []
+
+    def get(self, request, *args, **kwargs):
+        redirect_uri = "https://" + request.get_host() + request.get_full_path()
+        code = request.query_params.get('code', None)
+        referer_uri = request.query_params.get('referer_uri', None)
+        if code:
+            link_type = '?'
+            if "?" in referer_uri:
+                link_type = '&'
+            uri = referer_uri + link_type + 'code=' + code
+            return HttpResponseRedirect(uri)
+
+        else:
+            referer_uri = parse.quote(request.META['HTTP_REFERER'])
+            link_type = '?'
+            if "?" in referer_uri:
+                link_type = '&'
+            wechat_oauth = official_account_oauth(
+                redirect_uri + link_type + 'referer_uri=' + referer_uri, 'snsapi_userinfo')
+            url = wechat_oauth.authorize_url
+            return HttpResponseRedirect(url)
+
+
 class Current(APIView):
 
     def get(self, request, *args, **kwargs):
         wechat_id = jwt_get_wechatid_handler(request.auth)
-        queryset = WeChatUser.objects.get(pk=wechat_id)
-        data = WeChatUserSerializer(queryset).data
-        return Response(data)
+        if wechat_id:
+            queryset = WeChatUser.objects.get(pk=wechat_id)
+            data = WeChatUserSerializer(queryset).data
+            return Response(data)
+        else:
+            userid = jwt_get_userid_handler(request.auth)
+            queryset = User.objects.get(pk=userid)
+            data = UserSerializer(queryset).data
+            return Response(data)
 
 
 class Menu(APIView):
